@@ -26,8 +26,10 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions -fexceptions '
-           '-fexceptions   -O3',
+           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+           '-mbranch-protection=standard -fexceptions '
+           '-mbranch-protection=standard -fexceptions '
+           '-mbranch-protection=standard   -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.10/Modules/cjkcodecs/multibytecodec.h '
@@ -35,7 +37,7 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fexceptions',
+ 'CONFIGURE_CFLAGS': '-fexceptions -mbranch-protection=standard',
  'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Wno-complain-wrong-lang -Werror=format-security '
@@ -90,7 +92,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'build_alias=aarch64-redhat-linux-gnu' "
                 "'host_alias=aarch64-redhat-linux-gnu' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-fexceptions  ' 'LDFLAGS= ' 'CPPFLAGS='",
+                "'CC=gcc' 'CFLAGS=-fexceptions -mbranch-protection=standard  ' "
+                "'LDFLAGS= ' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
@@ -671,7 +674,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                     '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fexceptions -fexceptions   -O3 -flto=auto '
+                    '-mbranch-protection=standard -fexceptions '
+                    '-mbranch-protection=standard -fexceptions '
+                    '-mbranch-protection=standard   -O3 -flto=auto '
                     '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                     '-pipe -Wall -Wno-complain-wrong-lang '
                     '-Werror=format-security '
@@ -707,7 +712,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.10/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                   '-fexceptions -fexceptions -fexceptions   -O3 -flto=auto '
+                   '-fexceptions -mbranch-protection=standard -fexceptions '
+                   '-mbranch-protection=standard -fexceptions '
+                   '-mbranch-protection=standard   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Wno-complain-wrong-lang '
                    '-Werror=format-security '
@@ -745,7 +752,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
                     '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fexceptions -fexceptions   -O3 -flto=auto '
+                    '-mbranch-protection=standard -fexceptions '
+                    '-mbranch-protection=standard -fexceptions '
+                    '-mbranch-protection=standard   -O3 -flto=auto '
                     '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                     '-pipe -Wall -Wno-complain-wrong-lang '
                     '-Werror=format-security '
@@ -1106,7 +1115,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions',
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+        '-mbranch-protection=standard',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1142,7 +1152,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-fexceptions -fexceptions -fexceptions   -O3 '
+                             '-fexceptions -mbranch-protection=standard '
+                             '-fexceptions -mbranch-protection=standard '
+                             '-fexceptions -mbranch-protection=standard   -O3 '
                              '-flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Wno-complain-wrong-lang -Werror=format-security '
@@ -1180,7 +1192,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-              '-fexceptions -fexceptions   -O3',
+              '-mbranch-protection=standard -fexceptions '
+              '-mbranch-protection=standard -fexceptions '
+              '-mbranch-protection=standard   -O3',
  'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Wno-complain-wrong-lang -Werror=format-security '
@@ -1213,7 +1227,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                   '-fexceptions -fexceptions   -O3 -flto=auto '
+                   '-mbranch-protection=standard -fexceptions '
+                   '-mbranch-protection=standard -fexceptions '
+                   '-mbranch-protection=standard   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Wno-complain-wrong-lang '
                    '-Werror=format-security '
@@ -1285,7 +1301,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                         '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                        '-fexceptions -fexceptions   -O3 -flto=auto '
+                        '-mbranch-protection=standard -fexceptions '
+                        '-mbranch-protection=standard -fexceptions '
+                        '-mbranch-protection=standard   -O3 -flto=auto '
                         '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Wno-complain-wrong-lang -Werror=format-security '
